==> haskell-hls-cabal-plugin-2.1.0.0-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-plugin-2.1.0.0-EjM0oyVu8Id7WxCGcvXFnR
key:                  hls-cabal-plugin-2.1.0.0-EjM0oyVu8Id7WxCGcvXFnR
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  502285da3cfab4285b5c3e890750cbb4
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.1.0.0-EjM0oyVu8Id7WxCGcvXFnR
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 directory-1.3.8.5
    extra-1.7.16-8dGAsSrJDrL2Qv7CcA7Z6y filepath-1.4.300.1
    ghcide-2.1.0.0-1A8rZEuKOrJCB1jvVRxTcw
    hashable-1.4.7.0-2TMrYujL0SWBJEdw6jCOMM
    hls-graph-2.1.0.0-KhqnU3OmqNZCi273id0Gdx
    hls-plugin-api-2.1.0.0-5qxTNJQIyks35qN8jg8tLs
    lens-5.3.3-J3Ejqn7P12hA3GpyJcCxW8
    lsp-2.1.0.0-FB29snuVXiA2De2gdt0MPB
    lsp-types-2.0.1.0-IRNHyoiBlW21fnGL1eVD5I
    regex-tdfa-1.3.2.5-DTLCNeui6jjF7PuXyFzkbb stm-2.5.1.0 text-2.0.2
    text-rope-0.3-4aevqyCTM0D8x7ZpxZkNUa transformers-0.6.1.0
    unordered-containers-0.2.20.1-650icVWmHjf3WKXK0GKpae

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-plugin-2.1.0.0-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-plugin-2.1.0.0-3eMFKmwokmnJxg8QRlgF8k
key:                  hls-cabal-plugin-2.1.0.0-3eMFKmwokmnJxg8QRlgF8k
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e49c92ec1c2522feadaa36c3f05628f7
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.1.0.0-3eMFKmwokmnJxg8QRlgF8k
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 directory-1.3.8.5
    extra-1.7.16-8dGAsSrJDrL2Qv7CcA7Z6y filepath-1.4.300.1
    ghcide-2.1.0.0-CwrrvLiqxUL5aPxvByubHq
    hashable-1.4.7.0-2TMrYujL0SWBJEdw6jCOMM
    hls-graph-2.1.0.0-KhqnU3OmqNZCi273id0Gdx
    hls-plugin-api-2.1.0.0-5qxTNJQIyks35qN8jg8tLs
    lens-5.3.3-J3Ejqn7P12hA3GpyJcCxW8
    lsp-2.1.0.0-FB29snuVXiA2De2gdt0MPB
    lsp-types-2.0.1.0-IRNHyoiBlW21fnGL1eVD5I
    regex-tdfa-1.3.2.5-DTLCNeui6jjF7PuXyFzkbb stm-2.5.1.0 text-2.0.2
    text-rope-0.3-4aevqyCTM0D8x7ZpxZkNUa transformers-0.6.1.0
    unordered-containers-0.2.20.1-650icVWmHjf3WKXK0GKpae

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
